@@ -109,12 +109,17 @@ class HVAC(Consumer):
         # eta_percent / 100 -> eta decimal
         # p_set_kw * 1000 -> p_set_w
         # -> 1e1
-        subtrahend = self.config.eta_percent * next_state.p_kw * 1e1
+        subtrahend = (
+            self.config.eta_percent
+            * next_state.p_kw
+            * 1e1
+            * self.config.cool_factor
+        )
 
         dividend = minuend - subtrahend
         divisor = self.state.mass_kg * self.state.c_j_per_kg_k
 
         quotient = dividend / divisor
         next_state.theta_t_deg_celsius = self.state.theta_t_deg_celsius + (
-            self.inputs.step_size * quotient
+            self.inputs.step_size * quotient * self.config.thaw_factor
         )
