@@ -1,5 +1,5 @@
-"""This module contains a :class:`mosaik_api.Simulator` for the 
-flexiblity model, which is a wrapper for all models of the 
+"""This module contains a :class:`mosaik_api.Simulator` for the
+flexiblity model, which is a wrapper for all models of the
 pysimmods package.
 
 """
@@ -111,7 +111,7 @@ class FlexibilitySimulator(mosaik_api.Simulator):
             entities.append({"eid": eid, "type": model})
         return entities
 
-    def step(self, time, inputs):
+    def step(self, time, inputs, max_advance=0):
         """Perform a simulation step.
 
         Parameters
