@@ -9,6 +9,7 @@ from pysimmods.generator.dieselsim import DieselGenerator
 from pysimmods.generator.pvsystemsim import PVPlantSystem
 
 META = {
+    "type": "time-based",
     "models": {
         "Battery": {
             "public": True,
@@ -65,7 +66,7 @@ META = {
             "params": ["params", "inits"],
             "attrs": ["set_percent", "p_mw", "q_mvar"],
         },
-    }
+    },
 }
 
 MODELS = {
