@@ -2,9 +2,10 @@
 of the pysimmods package.
 
 """
+import pprint
 from datetime import datetime, timedelta
-import mosaik_api
 
+import mosaik_api
 from pysimmods.mosaik import LOG
 from pysimmods.util.dateformat import GER
 
@@ -12,7 +13,7 @@ from .meta import META, MODELS
 
 
 class PysimmodsSimulator(mosaik_api.Simulator):
-    """The Pysimmods simulator. """
+    """The Pysimmods simulator."""
 
     def __init__(self):
         super().__init__(META)
@@ -83,7 +84,7 @@ class PysimmodsSimulator(mosaik_api.Simulator):
 
         return entities
 
-    def step(self, time, inputs):
+    def step(self, time, inputs, max_advance=0):
         """Perform a simulation step.
 
         Parameters
@@ -100,7 +101,9 @@ class PysimmodsSimulator(mosaik_api.Simulator):
             The next step this simulator wants to be stepped.
 
         """
-        LOG.debug("At step %d: Received inputs: %s.", time, inputs)
+        LOG.debug(
+            "At step %d: Received inputs: %s.", time, pprint.pformat(inputs)
+        )
         # Set default inputs
         for eid, model in self.models.items():
             model.inputs.step_size = self.step_size
@@ -168,7 +171,7 @@ class PysimmodsSimulator(mosaik_api.Simulator):
 
                 data.setdefault(eid, dict())[attr] = value
 
-        LOG.debug("Gathered outputs: %s.", data)
+        LOG.debug("Gathered outputs: %s.", pprint.pformat(data))
         return data
 
 
